@@ -18,7 +18,6 @@ from swh.core.api.classes import stream_results
 from swh.model.model import Origin
 from swh.scheduler.cli import cli
 from swh.scheduler.utils import create_task_dict, utcnow
-from swh.storage import get_storage
 
 CLI_CONFIG = """
 scheduler:
@@ -596,16 +595,6 @@ def _fill_storage_with_origins(storage, nb_origins):
     return origins
 
 
-@pytest.fixture
-def storage():
-    """An instance of in-memory storage that gets injected
-    into the CLI functions."""
-    storage = get_storage(cls="memory")
-    with patch("swh.storage.get_storage") as get_storage_mock:
-        get_storage_mock.return_value = storage
-        yield storage
-
-
 @patch("swh.scheduler.cli.utils.TASK_BATCH_SIZE", 3)
 def test_task_schedule_origins_dry_run(swh_scheduler, storage):
     """Tests the scheduling when origin_batch_size*task_batch_size is a
